@@ -1,10 +1,11 @@
 """Support for communicating with myStrom bulbs."""
+
 import asyncio
 import logging
+from typing import Optional
 
 import aiohttp
 from yarl import URL
-from typing import Any, Dict, Iterable, List, Optional, Union
 
 from . import _request as request
 
@@ -17,8 +18,11 @@ class MyStromBulb:
     """A class for a myStrom bulb."""
 
     def __init__(
-        self, host: str, mac: str, session: aiohttp.client.ClientSession = None,
-    ):
+        self,
+        host: str,
+        mac: str,
+        session: aiohttp.client.ClientSession = None,
+    ) -> None:
         """Initialize the bulb."""
         self._close_session = False
         self._host = host
@@ -35,7 +39,7 @@ class MyStromBulb:
         self._transition_time = 0
         self.uri = URL.build(scheme="http", host=self._host).join(URI_BULB) / self._mac
 
-    async def get_state(self) -> object:
+    async def get_state(self) -> None:
         """Get the state of the bulb."""
         response = await request(self, uri=self.uri)
         self._consumption = response[self._mac]["power"]
@@ -52,7 +56,7 @@ class MyStromBulb:
         return self._firmware
 
     @property
-    def mac(self) -> float:
+    def mac(self) -> str:
         """Return the MAC address."""
         return self._mac
 
